@@ -34,8 +34,10 @@ type options = {
   block_driver : guestcaps_block_type;
   keep_serial_console : bool;
   ks : key_store;
+  memsize : int option;
   network_map : Networks.t;
   root_choice : root_choice;
+  smp : int option;
   static_ips : static_ip list;
   customize_ops : Customize_cmdline.ops;
 }
@@ -53,11 +55,28 @@ let rec convert input_disks options source =
 
   message (f_"Opening the source");
   let g = open_guestfs ~identifier:"v2v" () in
-  g#set_memsize (g#get_memsize () * 2);
-  (* Setting the number of vCPUs allows parallel mkinitrd, but make
-   * sure this is not too large because each vCPU consumes guest RAM.
-   *)
-  g#set_smp (min 8 (Sysconf.nr_processors_online ()));
+  let memsize =
+    match options.memsize with
+    | None ->
+       (* Default (if [--memsize] option is not used) is to calculate
+        * some multiple of the libguestfs default memory size.
+        *)
+       g#get_memsize () * 2
+    | Some memsize -> memsize in
+  g#set_memsize memsize;
+  let smp =
+    match options.smp with
+    | None ->
+       (* Default (if [--smp] option is not used) is to set the number
+        * according to the number of physical CPUs on the host, but
+        * limit it because each vCPU consumes guest RAM.  This is
+        * necessary to allow parallel mkinitrd which greatly improves
+        * performance.
+        *)
+       min 8 (Sysconf.nr_processors_online ())
+    | Some smp -> smp in
+  g#set_smp smp;
+
   (* The network is used by the unconfigure_vmware () function, and the "--key
    * ID:clevis" command line options (if any). *)
   g#set_network true;
@@ -94,6 +113,10 @@ let rec convert input_disks options source =
   let root = Choose_root.choose_root options.root_choice g in
   let inspect = Mount_filesystems.mount_filesystems g root in
 
+  (* Detect boot device. *)
+  message (f_"Detecting the boot device");
+  let target_boot_device = get_target_boot_device g inspect in
+
   let mpstats = get_mpstats g in
   check_guest_free_space inspect mpstats;
 
@@ -135,7 +158,8 @@ let rec convert input_disks options source =
     get_target_firmware i_firmware guestcaps source output in
 
   (* Create target metadata file. *)
-  let target_meta = { guestcaps; target_buses; target_firmware; target_nics } in
+  let target_meta = { guestcaps; target_buses; target_nics;
+                      target_firmware; target_boot_device } in
 
   (* This is a good place to dump everything we know about the guest. *)
   if verbose () then debug_info source inspect target_meta mpstats;
@@ -360,12 +384,44 @@ and get_target_firmware i_firmware guestcaps source output =
 
   target_firmware
 
+and get_target_boot_device g inspect =
+  (* We only do it for Linux, as most likely Windows never(?) boots
+   * from any drive other than C:.  We can revisit this decision
+   * if someone reports a bug.
+   *)
+  match inspect.i_type with
+  | "linux" ->
+     (try
+        (* In sane cases, the Grub stage1/boot.img (ie. the boot sector) is
+         * always on the same drive as /boot.  So we can just find out
+         * where /boot is mounted and use that.
+         *)
+        let boot_mountpoint = List.assoc "/boot" inspect.i_mountpoints in
+        let boot_device = g#part_to_dev boot_mountpoint in
+        let boot_device = g#device_index boot_device in
+        Some boot_device
+      with
+      | Not_found -> None
+      | G.Error msg
+           (* Returned by part_to_dev if the /boot mountpoint is not
+            * a partition name.
+            *)
+           when String.find msg "device name is not a partition" >= 0 -> None
+      | G.Error msg
+           (* Returned by device_index if the /boot device is not
+            * a normal drive name (eg. /dev/mdX).
+            *)
+           when String.find msg "device not found" >= 0 -> None
+     )
+  | _ -> None
+
 (* After conversion we dump as much information about the guest
  * as we can in one place.  Note this is only called when verbose
  * is enabled.
  *)
 and debug_info source inspect
-               { guestcaps; target_buses; target_firmware; target_nics }
+               { guestcaps; target_buses; target_nics;
+                 target_firmware; target_boot_device }
                mpstats =
   eprintf "info:\n";
   eprintf "%s\n" (string_of_source source);
@@ -373,6 +429,8 @@ and debug_info source inspect
   eprintf "%s\n" (string_of_guestcaps guestcaps);
   eprintf "%s\n" (string_of_target_buses target_buses);
   eprintf "target firmware: %s\n" (string_of_target_firmware target_firmware);
+  eprintf "target boot device: %s\n"
+    (match target_boot_device with None -> "" | Some i -> string_of_int i);
   eprintf "target NICs:\n";
   List.iter (fun nic -> eprintf "%s\n" (string_of_source_nic nic))
     target_nics;
