@@ -53,6 +53,8 @@ module VDDK = struct
 
 All other settings are optional:
 
+  -io vddk-compression=COMPR   Set VDDK compression mode (see
+                                 nbdkit-vddk-plugin documentation)
   -io vddk-config=FILE         VDDK configuration file
   -io vddk-cookie=COOKIE       VDDK cookie
   -io vddk-file=FILE           Override nbdkit-vddk-plugin file= parameter
@@ -73,7 +75,8 @@ information on these settings.
      * Also removes the "vddk-" prefix from the internal list.
      *)
     let vddk_option_keys =
-      [ "config";
+      [ "compression";
+        "config";
         "cookie";
         "file";
         "libdir";
@@ -198,6 +201,8 @@ information on these settings.
       | Some password_file ->
          password_file in
 
+    let compression =
+      try Some (List.assoc "compression" io_options) with Not_found -> None in
     let config =
       try Some (List.assoc "config" io_options) with Not_found -> None in
     let cookie =
@@ -281,8 +286,8 @@ See also the virt-v2v-input-vmware(1) manual.") libNN
     error_unless_nbdkit_vddk_working ();
 
     (* Helper to create an nbdkit command object. *)
-    let create_nbdkit_vddk () =
-      let cmd = Nbdkit.create "vddk" in
+    let create_nbdkit_vddk ?name () =
+      let cmd = Nbdkit.create ?name "vddk" in
 
       (* Suppress datapath messages. *)
       Nbdkit.add_debug_flag cmd "vddk.datapath" "0";
@@ -299,6 +304,7 @@ See also the virt-v2v-input-vmware(1) manual.") libNN
 
       (* The passthrough parameters. *)
       let passthru cmd name v = Option.iter (Nbdkit.add_arg cmd name) v in
+      passthru cmd "compression" compression;
       passthru cmd "config" config;
       passthru cmd "cookie" cookie;
       passthru cmd "libdir" libdir;
@@ -431,7 +437,7 @@ See also the virt-v2v-input-vmware(1) manual.") libNN
         let socket = sprintf "%s/in0" dir in
         On_exit.unlink socket;
 
-        let nbdkit = create_nbdkit_vddk () in
+        let nbdkit = create_nbdkit_vddk ~name:"in" () in
         Nbdkit.add_arg nbdkit "export" wildcard;
         let _, pid = Nbdkit.run_unix socket nbdkit in
         On_exit.kill pid;
@@ -442,10 +448,11 @@ See also the virt-v2v-input-vmware(1) manual.") libNN
         (* Create an nbdkit instance for each disk. *)
         List.mapi (
           fun i file ->
-            let socket = sprintf "%s/in%d" dir i in
+            let sockname = sprintf "in%d" i in
+            let socket = sprintf "%s/%s" dir sockname in
             On_exit.unlink socket;
 
-            let nbdkit = create_nbdkit_vddk () in
+            let nbdkit = create_nbdkit_vddk ~name:sockname () in
             Nbdkit.add_arg nbdkit "file" file;
             let _, pid = Nbdkit.run_unix socket nbdkit in
             On_exit.kill pid;
