@@ -39,3 +39,15 @@ val nbdcopy : string
 
 val nbdinfo : string
 (** The location of the nbdinfo program, from configure value [@NBDINFO@] *)
+
+val enable_block_driver : bool
+(** True if [--block-driver] option is enabled *)
+
+val enable_xen : bool
+(** True if Xen input is enabled *)
+
+val enable_glance : bool
+(** True if [-o glance] output mode is enabled *)
+
+val enable_ovirt : bool
+(** True if oVirt output modes are enabled *)
